## $Id: viewlets.py 11607 2014-04-30 05:30:32Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.component import getUtility
from waeup.kofa.students.interfaces import IStudent, IStudentsUtils
from waeup.kofa.students.workflow import PAID
from waeup.kofa.students.viewlets import (
    AddPreviousPaymentActionButton, AddBalancePaymentActionButton,
    ManageActionButton, StudentBaseDisplayFormPage)

from waeup.aaue.interfaces import MessageFactory as _

class AddPreviousPaymentActionButton(AddPreviousPaymentActionButton):

    @property
    def target_url(self):
        return ''

class AddBalancePaymentActionButton(AddBalancePaymentActionButton):

    @property
    def target_url(self):
        return ''

class GetMatricNumberActionButton(ManageActionButton):
    grok.order(10)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    #grok.require('waeup.manageStudent')
    icon = 'actionicon_count.png'
    text = _('Get Matriculation Number')

    @property
    def target_url(self):
        students_utils = getUtility(IStudentsUtils)
        if self.context.matric_number:
            return ''
        matric_number = students_utils.constructMatricNumber(self.context)
        if not matric_number:
            return ''
        return self.view.url(self.view.context, 'get_matric_number')

class MatricNumberSlipActionButton(ManageActionButton):
    grok.order(10)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download matriculation number slip')
    target = 'matric_number_slip.pdf'

    @property
    def target_url(self):
        if self.context.state not in (PAID,) or not self.context.is_fresh \
            or not self.context.matric_number:
            return ''
        return self.view.url(self.view.context, self.target)